@@ -7,9 +7,61 @@ use swc_css_parser::{
     parse_tokens,
     parser::{input::ParserInput, Parser, ParserConfig},
 };
-use swc_css_visit::{Visit, VisitWith};
+use swc_css_visit::{Node, Visit, VisitWith};
 use testing::NormalizedOutput;
 
+struct AssertValid;
+
+impl Visit for AssertValid {
+    fn visit_pseudo_selector(&mut self, s: &PseudoSelector, _: &dyn Node) {
+        s.visit_children_with(self);
+
+        if s.args.tokens.is_empty() {
+            return;
+        }
+
+        match &s.args.tokens[0].token {
+            Token::Colon | Token::Num(..) => return,
+            _ => {}
+        }
+
+        let _selectors: Vec<ComplexSelector> =
+            parse_tokens(&s.args, ParserConfig { parse_values: true })
+                .unwrap_or_else(|err| panic!("failed to parse tokens: {:?}\n{:?}", err, s.args));
+    }
+}
+
+#[testing::fixture("tests/fixture/**/input.css")]
+fn tokens_input(input: PathBuf) {
+    eprintln!("Input: {}", input.display());
+
+    testing::run_test2(false, |cm, _handler| {
+        let fm = cm.load_file(&input).unwrap();
+
+        let tokens = {
+            let mut lexer = Lexer::new(SourceFileInput::from(&*fm));
+
+            let mut tokens = vec![];
+
+            while let Ok(t) = lexer.next() {
+                tokens.push(t);
+            }
+            Tokens {
+                span: Span::new(fm.start_pos, fm.end_pos, Default::default()),
+                tokens,
+            }
+        };
+
+        let ss: Stylesheet = parse_tokens(&tokens, ParserConfig { parse_values: true })
+            .expect("failed to parse tokens");
+
+        ss.visit_with(&Invalid { span: DUMMY_SP }, &mut AssertValid);
+
+        Ok(())
+    })
+    .unwrap();
+}
+
 #[testing::fixture("tests/fixture/**/input.css")]
 fn pass(input: PathBuf) {
     eprintln!("Input: {}", input.display());
